/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.field.model;

import com.vividsolutions.jts.geom.Geometry;
import java.awt.Color;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import nl.cloudfarming.client.geoviewer.Geometrical;
import nl.cloudfarming.client.geoviewer.Palette;
import nl.cloudfarming.client.geoviewer.render.GeoTranslator;
import nl.cloudfarming.client.geoviewer.render.GeometricalWidget;
import org.jdesktop.swingx.color.ColorUtil;
import org.netbeans.api.visual.model.ObjectScene;
import org.netbeans.api.visual.model.ObjectState;
import org.openide.util.NbBundle;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
@NbBundle.Messages({"ShapeWidget tooltip name=Name:","ShapeWidget tooltip value=Value:"})
public class ShapeWidget extends GeometricalWidget {

    private final Shape shape;
    
    public ShapeWidget(ObjectScene scene, GeoTranslator geoTranslator, Geometrical geometrical, Palette palette, Geometry envelope) {
        super(scene, geoTranslator, geometrical, palette, envelope);
        assert geometrical instanceof Shape:"Provided geometrical should be castable to Shape";
        shape = (Shape)geometrical;
        setForeground(palette.getColorForValue(shape.getImportType()));
        updateTooltip();
        shape.addPropertyChangeListener(new PropertyChangeListener() {

            @Override
            public void propertyChange(PropertyChangeEvent evt) {
                if(Shape.PROP_IMPORT_TYPE.equals(evt.getPropertyName())){
                    setForeground(getPalette().getColorForValue(shape.getImportType()));
                    repaint();
                }
                if(Shape.PROP_NAME.equals(evt.getPropertyName())|| Shape.PROP_VALUE.equals(evt.getPropertyName())){
                    updateTooltip();
                }
            }
        });
    }
    
    private void updateTooltip(){
        StringBuilder sb = new StringBuilder(Bundle.ShapeWidget_tooltip_name());
        sb.append(shape.getName());
        sb.append("\n");
        sb.append(Bundle.ShapeWidget_tooltip_value());
        sb.append(shape.getValue());
        setToolTipText(sb.toString());
        
    }
    
    /**
     * overide to prevent state change to change color, we want value based colors in the ShapeWidget
     * instead of state based. Use alpha channel of statebase colors to set alpha on current foreground
     * @param previousState
     * @param state 
     */
    @Override
    protected void notifyStateChanged(ObjectState previousState, ObjectState state) {
        Color c = getPalette().getColorForState(state);
        Color foreground = getForeground();
        setForeground(ColorUtil.setAlpha(foreground, c.getAlpha()));
        repaint();
    }
    
}
