/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.field.model;

import org.openide.util.NbBundle;

/**
 * Enum which describes the different soil types
 * @author Merijn Zengers
 */
@NbBundle.Messages({"Soiltype KY=clay",
                    "Soiltype KV=peat",
                    "Soiltype DZ=sand",
                    "Soiltype LO=loess"})
public enum SoilType {
    CLAY("KY"),
    PEAT("KV"),
    SAND("DZ"),
    LOESS("LO");
    
    private String code;
    private String description;
    
    private final String BUNDLE_PREFIX = "Soiltype ";
    
    SoilType(String code){
        this.code = code;
        this.description = !code.isEmpty() ? NbBundle.getMessage(getClass(), BUNDLE_PREFIX + code) : "";
    }

    /**
     * Get the code of the soil type
     * @return 
     */
    public String getCode() {
        return code;
    }

    /**
     * Get the description of the soil type
     * @return 
     */
    public String getDescription() {
        return description;
    }

    @Override
    public String toString() {
        return description;
    }    
}
